<?php

/**
 * @file
 * Contains \Drupal\admin_feedback\Form\AdminFeedbackSettingsForm.
 */

namespace Drupal\admin_feedback\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * AdminFeedback Settings Form.
 */
class AdminFeedbackSettingsForm extends ConfigFormBase {
  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'admin_feedback.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'admin_feedback_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('admin_feedback.settings');

    $form['initial_question'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Initial question'),
      '#description' => $this->t('The question that initially appears above the yes and no buttons.'),
      '#default_value' => $config->get('initial_question'),
      '#required' => TRUE,
    ];
    $form['yes_button'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Yes button text'),
      '#description' => $this->t('Text that appears on the Yes button in the Feedback Block'),
      '#default_value' => $config->get('yes_button'),
      '#required' => TRUE,
    ];
    $form['yes_response'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Yes response'),
      '#description' => $this->t('Response that appears when the user selects Yes.'),
      '#default_value' => $config->get('yes_response'),
      '#required' => TRUE,
    ];
    $form['no_button'] = [
      '#type' => 'textfield',
      '#title' => $this->t('No button text'),
      '#description' => $this->t('Text that appears on the No button in the Feedback Block'),
      '#default_value' => $config->get('no_button'),
      '#required' => TRUE,
    ];
    $form['no_response'] = [
      '#type' => 'textfield',
      '#title' => $this->t('No response'),
      '#description' => $this->t('Response that appears when the user selects No.'),
      '#default_value' => $config->get('no_response'),
      '#required' => TRUE,
    ];
    $form['feedback_prompt'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Feedback prompt'),
      '#description' => $this->t('Text that requests additional feedback after the user has selected an option.'),
      '#default_value' => $config->get('feedback_prompt'),
      '#required' => TRUE,
    ];
    $form['submit_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Submit button text'),
      '#description' => $this->t('Text in the button the user uses to submit their additional feedback.'),
      '#default_value' => $config->get('submit_text'),
      '#required' => TRUE,
    ];
    $form['final_response'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Final response'),
      '#description' => $this->t('Response that appears when the user has submitted additional feedback.'),
      '#default_value' => $config->get('final_response'),
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('admin_feedback.settings')
      ->set('initial_question', $form_state->getValue('initial_question'))
      ->set('yes_button', $form_state->getValue('yes_button'))
      ->set('yes_response', $form_state->getValue('yes_response'))
      ->set('no_button', $form_state->getValue('no_button'))
      ->set('no_response', $form_state->getValue('no_response'))
      ->set('feedback_prompt', $form_state->getValue('feedback_prompt'))
      ->set('submit_text', $form_state->getValue('submit_text'))
      ->set('final_response', $form_state->getValue('final_response'))
      ->save();
  }

}
